@@ -753,7 +753,7 @@ class Discourse(object):
 
     def emails_check(self, email):
         try:
-            self.d._get(f'/u/check_email?email={email}')
+            self.d._get('/u/check_email', email=email)
             return True
         except DiscourseClientError:
             return False
